pro ssw_average_images, index, data, sindex, sdata, $
      ref_image=ref_image, above_radius=above_radius, disk=disk, $
      annulus=annulus, invert_limb=invert_limb, sum_images=sum_images, $
      debug=debug
;+
;   Name: ssw_sum_images
;
;   Purpose: sum/average N-images, optionally only above limb, annulus, etc.
;
;   Input Parameters:
;      index, data - any SSW standards, assume more than 1 image
;      
;   Output Parameters:
;      sindex, sdata - the summed/averaged output image with history added
;
;   Keyword Parameters:
;      ref_image - reference image number or index - default is midpoint
;      above_radius - only sum/average above this raduis (floating point ok)
;                     [ 1.0=photospheric limb ]
;      disk - only sum/average on-disk pixels
;      annulus - optional 2 element annulus, in radii - for example [1.0,1.2]
;      invert - optionally, invert the summed/averaged pixels
;      sum_images - if set, just sum not average desired pixels
;
;   History:
;      16-Nov-2000 - S.L.Freeland
;   
;   Restrictions:
;      assume image alignment done prior to call 
;-
debug=keyword_set(debug)
sum_images=keyword_set(sum_images)

nimg=data_chk(data,/nimage)
if nimg lt 2 or nimg ne n_elements(index) then begin 
   box_message,['Need at least 2 images (index,data)',$
                'IDL> ssw_average_images, index, data, sindex,sdata,[KEYWORDS]']
   return
endif

; select reference
case 1 of 
   data_chk(ref_image,/struct):   refss=tim2dset(index,ref_image)
   data_chk(ref_image,/undefined):refss=nimg/2
   else: refss=ref_image(0)
endcase

allmask=make_array(data_chk(data,/nx),data_chk(data,/ny),/long,value=1)

; select solar mask, if any
mtype='No mask'
case 1 of 
   keyword_set(above_radius): begin
      smask=solar_mask(index(refss),data(*,*,refss),/outside)
      mtype='above_radius ' + string(above_radius,format='(f3.1)')
   endcase

   keyword_set(annulus): begin
      smask=solar_mask(index(refss),data(*,*,refss),annulus=annulus)
      mtype='annulus ' + string(annulus,format='(2f3.1)')
   endcase

   keyword_set(disk): begin
      smask=solar_mask(index(refss),data(*,*,refss))
      mtype='disk'
   endcase

   else: smask=allmask
endcase
rmask=1-smask               ; inverted mask (non summed/averaged)

summ=keyword_set(sum_images)
spart=(total(data,3)  * smask)/([nimg,1])(sum_images)
rpart=data(*,*,refss) * rmask

;if keyword_set(invert) then spart=

sdata=spart + rpart                ; output summed + non-summed parts

; define output index including history
sindex=index(refss)
mtype=(['Averaged','Summed'])(summ) + ' ' + 'Masking: ' + mtype
update_history,sindex,mtype
update_history,sindex,anytim(index,/ecs)

if debug then stop
return
end
